@@ -13,6 +13,9 @@
 #' @param dst a data frame containing destination points identifiers, longitudes 
 #' and latitudes (WGS84). It can also be a SpatialPointsDataFrame or a 
 #' SpatialPolygonsDataFrame, then row names are used as identifiers. 
+#' @param gepaf a boolean indicating if coordinates are sent encoded with the
+#' google encoded algorithm format (TRUE) or not (FALSE). Must be FALSE if using
+#' the public OSRM API.
 #' @return A list containing 3 data frames is returned. 
 #' durations is the matrix of travel times (in minutes), 
 #' sources and destinations are the coordinates of 
@@ -20,43 +23,40 @@
 #' times (WGS84).
 #' @details If loc, src or dst are data frames we assume that the 3 first 
 #' columns of the data.frame are: identifiers, longitudes and latitudes. 
-#' @note The public OSRM API does not allow more than 10 000 
-#' distances in query result. \cr
-#' If you use an other OSRM API service, make sure that 
-#' more distances are allowed in results 
-#' (i.e. the "max-table-size" argument, Max. locations supported in distance 
-#' table query).
+#' @note 
+#' If you want to get a large number of distances make sure to set the 
+#' "max-table-size" argument (Max. locations supported in table) of the OSRM 
+#' server accordingly.
 #' @seealso \link{osrmIsochrone}
 #' @examples
 #' \dontrun{
 #' # Load data
-#' data("com")
+#' data("berlin")
 #' 
-#' # Inputs are data frames  
+#' # Inputs are data frames
 #' # Travel time matrix
-#' distCom <- osrmTable(loc = com[1:50, c("comm_id","lon","lat")])
+#' distA <- osrmTable(loc = apotheke.df[1:50, c("id","lon","lat")])
 #' # First 5 rows and columns
-#' distCom$durations[1:5,1:5]
+#' distA$durations[1:5,1:5]
 #' 
 #' # Travel time matrix with different sets of origins and destinations
-#' distCom2 <- osrmTable(src = com[1:10,c("comm_id","lon","lat")],
-#'                       dst = com[11:20,c("comm_id","lon","lat")])
+#' distA2 <- osrmTable(src = apotheke.df[1:10,c("id","lon","lat")],
+#'                     dst = apotheke.df[11:20,c("id","lon","lat")])
 #' # First 5 rows and columns
-#' distCom2$durations[1:5,1:5]
-#' 
+#' distA2$durations[1:5,1:5]
 #' 
 #' # Inputs are SpatialPointsDataFrames
-#' distCom <- osrmTable(loc = src)
+#' distA3 <- osrmTable(loc = apotheke.sp[1:10,])
 #' # First 5 rows and columns
-#' distCom$durations[1:5,1:5]
+#' distA3$durations[1:5,1:5]
 #' 
 #' # Travel time matrix with different sets of origins and destinations
-#' distCom2 <- osrmTable(src = src, dst = dst)
+#' distA4 <- osrmTable(src = apotheke.sp[1:10,], dst = apotheke.sp[11:20,])
 #' # First 5 rows and columns
-#' distCom2$durations[1:5,1:5]
+#' distA4$durations[1:5,1:5]
 #' }
 #' @export
-osrmTable <- function(loc, src = NULL, dst = NULL){
+osrmTable <- function(loc, src = NULL, dst = NULL, gepaf = FALSE){
   tryCatch({
     if (is.null(src)){
       # check if inpout is sp, transform and name columns
@@ -65,16 +65,11 @@ osrmTable <- function(loc, src = NULL, dst = NULL){
       }else{
         names(loc) <- c("id", "lon", "lat")
       }
-      
-      # Check query size
-      osrmLimit(nSrc = nrow(loc), nDst = nrow(loc))
-      
       # Format
       src <- loc
       dst <- loc
-
       # Build the query
-      req <- tableLoc(loc = loc)
+      req <- tableLoc(loc = loc, gepaf = gepaf)
     }else{
       # check if inpout is sp, transform and name columns
       if(testSp(src)){
@@ -88,38 +83,34 @@ osrmTable <- function(loc, src = NULL, dst = NULL){
       }else{
         names(dst) <- c("id", "lon", "lat")
       }
-      
-      # Check query size
-      osrmLimit(nSrc = nrow(src), nDst = nrow(dst))
-      
+
       # Build the query
       loc <- rbind(src, dst)
 
-      req <- paste(tableLoc(loc = loc),
+      req <- paste(tableLoc(loc = loc, gepaf = gepaf),
                    "?sources=", 
                    paste(0:(nrow(src)-1), collapse = ";"), 
                    "&destinations=", 
                    paste(nrow(src):(nrow(loc)-1), collapse = ";"), 
                    sep="")
     }
-
+    
+    req <- utils::URLencode(req)
+    
+    osrmLimit(nSrc = nrow(src), nDst = nrow(dst), nreq = nchar(req))
+    
     
     # Get the result
-    resRaw <- RCurl::getURL(utils::URLencode(req), 
+    resRaw <- RCurl::getURL(req, 
                             useragent = "'osrm' R package")
-    # Error if URL is too long
-    e <- simpleError("Something went wrong. It could be that the URL sent to the OSRM public API is too long. 
-         Try to enter less sources or destinations.")
-    if(getOption("osrm.server") == "http://router.project-osrm.org/" & resRaw==""){
-      stop(e)
-    }
+    
     # Parse the results
     res <- jsonlite::fromJSON(resRaw)
-    
+
     # Check results
-    e <- simpleError(res$message)
+    e <- simpleError(paste0(res$code,"\n",res$message))
     if(res$code != "Ok"){stop(e)}
-    
+
     # get the distance table
     durations <- distTableFormat(res = res, src = src, dst = dst)
     
@@ -129,7 +120,7 @@ osrmTable <- function(loc, src = NULL, dst = NULL){
     return(list(durations = durations, 
                 sources = coords$sources, 
                 destinations = coords$destinations))
-  }, error=function(e) {message("osrmTable function returns an error: \n", e)})
+  }, error=function(e) {message("OSRM returned an error:\n", e)})
   return(NULL)
 }
 
